From 29c3570901e1c145dce57824ddc9276fddf0d808 Mon Sep 17 00:00:00 2001
From: Nicolas Dufresne <nicolas.dufresne@collabora.com>
Date: Tue, 6 Aug 2019 22:27:40 -0400
Subject: [PATCH] v4l2: Fix type compatibility issue with glibc 2.30

From now on, we will use linux/types.h on Linux, and use typedef of the
various flavour of BSD.

Fixes #635
---
 sys/v4l2/ext/types-compat.h | 21 ++++++++++++++-------
 1 file changed, 14 insertions(+), 7 deletions(-)

diff --git a/sys/v4l2/ext/types-compat.h b/sys/v4l2/ext/types-compat.h
index d3673dd49..ea21c9513 100644
--- a/sys/v4l2/ext/types-compat.h
+++ b/sys/v4l2/ext/types-compat.h
@@ -24,6 +24,11 @@
 #ifndef __TYPES_COMPAT_H__
 #define __TYPES_COMPAT_H__
 
+#ifdef   __linux__
+#include <linux/types.h>
+#include <asm/ioctl.h>
+
+#else /* One of the BSDs */
 /* From linux/types.h */
 #ifndef __bitwise__
 #  ifdef __CHECKER__
@@ -41,12 +46,14 @@
 #  endif
 #endif
 
-#define __u64 guint64
-#define __u32 guint32
-#define __u16 guint16
-#define __u8 guint8
-#define __s64 gint64
-#define __s32 gint32
-#define __le32 guint32 __bitwise
+typedef guint8  __u8;
+typedef guint16 __u16;
+typedef gint32  __s32;
+typedef guint32 __u32;
+typedef gint64  __s64;
+typedef guint64 __u64;
+typedef guint32 __bitwise __le32;
+
+#endif
 
 #endif /* __TYPES_COMPAT_H__ */
-- 
2.22.0

